(_api_prior)=
# Priors
```{eval-rst}
.. autosummary::
    :toctree: generated/

    skretrieval.retrieval.prior.VerticalTikhonov
    skretrieval.retrieval.prior.ManualPrior
    skretrieval.retrieval.prior.ConstantDiagonalPrior

```
